summaryrefslogtreecommitdiff
path: root/forms
diff options
context:
space:
mode:
authorKenneth Beck <overlordkb.dev@gmail.com>2013-03-01 23:33:49 -0600
committerStephan Bergmann <sbergman@redhat.com>2013-03-06 10:39:30 +0100
commit21e1e859a7dc883a0347b6537e2518f4b2e9d0ff (patch)
tree144fb3c0960eecba48c322e0813423747c4ade1c /forms
parent0ece7f368b499a010e3ecf2ffa193c242f9a78db (diff)
fdo#60724 change spelling error REMOVEABLE -> REMOVABLE
Only applies to PropertyAttribute::REMOVEABLE, and all instances in comments. All other instances of the misspelling have remained the same. Example: AF_REMOVEABLE Change-Id: I391f4101bbc3e06689318235a37d616065bc1686 Signed-off-by: Stephan Bergmann <sbergman@redhat.com>
Diffstat (limited to 'forms')
-rw-r--r--forms/qa/integration/forms/FormPropertyBags.java4
-rw-r--r--forms/source/component/propertybaghelper.cxx10
2 files changed, 7 insertions, 7 deletions
diff --git a/forms/qa/integration/forms/FormPropertyBags.java b/forms/qa/integration/forms/FormPropertyBags.java
index baa2b7b5b73e..47f50541582d 100644
--- a/forms/qa/integration/forms/FormPropertyBags.java
+++ b/forms/qa/integration/forms/FormPropertyBags.java
@@ -103,8 +103,8 @@ public class FormPropertyBags extends complexlib.ComplexTestCase implements XPro
propContainer.addProperty( "SomeNumericValue", PropertyAttribute.BOUND, new Integer( 42 ) );
XPropertySetInfo propertyInfo = textFieldModel.getPropertySetInfo();
- assure( "Per service definition, dynamic properties are expected to be forced to be removeable",
- ( propertyInfo.getPropertyByName("SomeBoundText").Attributes & PropertyAttribute.REMOVEABLE ) != 0 );
+ assure( "Per service definition, dynamic properties are expected to be forced to be removable",
+ ( propertyInfo.getPropertyByName("SomeBoundText").Attributes & PropertyAttribute.REMOVABLE ) != 0 );
// a second addition of a property with an existent name should be rejected
boolean caughtExpected = false;
diff --git a/forms/source/component/propertybaghelper.cxx b/forms/source/component/propertybaghelper.cxx
index a9ababe50048..e36e8fd18763 100644
--- a/forms/source/component/propertybaghelper.cxx
+++ b/forms/source/component/propertybaghelper.cxx
@@ -194,9 +194,9 @@ namespace frm
throw PropertyExistException( _rName, m_rContext.getPropertiesInterface() );
//----------------------------------------------
- // normalize the REMOVEABLE attribute - the FormComponent service
- // requires that all dynamic properties are REMOVEABLE
- _nAttributes |= PropertyAttribute::REMOVEABLE;
+ // normalize the REMOVABLE attribute - the FormComponent service
+ // requires that all dynamic properties are REMOVABLE
+ _nAttributes |= PropertyAttribute::REMOVABLE;
//----------------------------------------------
// find a free handle
@@ -214,11 +214,11 @@ namespace frm
::osl::MutexGuard aGuard( m_rContext.getMutex() );
impl_nts_checkDisposed_throw();
// check whether it's removeable at all
Reference< XMultiPropertySet > xMe( m_rContext.getPropertiesInterface(), UNO_QUERY_THROW );
Reference< XPropertySetInfo > xPSI( xMe->getPropertySetInfo(), UNO_QUERY_THROW );
Property aProperty( xPSI->getPropertyByName( _rName ) );
- if ( ( aProperty.Attributes & PropertyAttribute::REMOVEABLE ) == 0 )
+ if ( ( aProperty.Attributes & PropertyAttribute::REMOVABLE ) == 0 )
throw NotRemoveableException( _rName, xMe );
m_aDynamicProperties.removeProperty( _rName );
@@ -214,11 +214,11 @@ namespace frm
::osl::MutexGuard aGuard( m_rContext.getMutex() );
impl_nts_checkDisposed_throw();
- // check whether it's removeable at all
+ // check whether it's removable at all
Reference< XMultiPropertySet > xMe( m_rContext.getPropertiesInterface(), UNO_QUERY_THROW );
Reference< XPropertySetInfo > xPSI( xMe->getPropertySetInfo(), UNO_QUERY_THROW );